@@ -30,7 +30,7 @@
  * A typical simple observer would look liks this:
  * |[
  * static void
- * my_observe_channels (TpSimpleObserver *self,
+ * my_observe_channels (TpSimpleObserver *observer,
  *    TpAccount *account,
  *    TpConnection *connection,
  *    GList *channels,
@@ -76,7 +76,7 @@
 
 /**
  * TpSimpleObserverObserveChannelsImpl:
- * @self: a #TpSimpleObserver instance
+ * @observer: a #TpSimpleObserver instance
  * @account: a #TpAccount having %TP_ACCOUNT_FEATURE_CORE prepared if possible
  * @connection: a #TpConnection having %TP_CONNECTION_FEATURE_CORE prepared
  * if possible
@@ -239,7 +239,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
    * TpSimpleObserver:callback:
    *
    * The TpSimpleObserverObserveChannelsImpl callback implementing the
-   * ObserverChannels D-Bus method.
+   * ObserveChannels D-Bus method.
    *
    * This property can't be %NULL.
    *
@@ -247,7 +247,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
    */
   param_spec = g_param_spec_pointer ("callback",
       "Callback",
-      "Function called when ObserverChannels is called",
+      "Function called when ObserveChannels is called",
       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_CALLBACK,
       param_spec);
@@ -256,12 +256,12 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
    * TpSimpleObserver:user-data:
    *
    * The user-data pointer passed to the callback implementing the
-   * ObserverChannels D-Bus method.
+   * ObserveChannels D-Bus method.
    *
    * Since: 0.11.5
    */
   param_spec = g_param_spec_pointer ("user-data", "user data",
-      "pointer passed as user-data when ObserverChannels is called",
+      "pointer passed as user-data when ObserveChannels is called",
       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_USER_DATA,
       param_spec);
@@ -288,8 +288,8 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
  * @dbus: a #TpDBusDaemon object, may not be %NULL
  * @recover: the value of the Observer.Recover D-Bus property
  * @name: the name of the Observer (see #TpBaseClient:name: for details)
- * @unique: the value of the TpBaseClient:uniquify-name: property
- * @callback: the function called when ObserverChannels is called
+ * @uniquify: the value of the #TpBaseClient:uniquify-name: property
+ * @callback: the function called when ObserveChannels is called
  * @user_data: arbitrary user-supplied data passed to @callback
  * @destroy: called with the user_data as argument, when the #TpSimpleObserver
  * is destroyed
@@ -308,7 +308,7 @@ TpBaseClient *
 tp_simple_observer_new (TpDBusDaemon *dbus,
     gboolean recover,
     const gchar *name,
-    gboolean unique,
+    gboolean uniquify,
     TpSimpleObserverObserveChannelsImpl callback,
     gpointer user_data,
     GDestroyNotify destroy)
@@ -317,7 +317,7 @@ tp_simple_observer_new (TpDBusDaemon *dbus,
       "dbus-daemon", dbus,
       "recover", recover,
       "name", name,
-      "uniquify-name", unique,
+      "uniquify-name", uniquify,
       "callback", callback,
       "user-data", user_data,
       "destroy", destroy,
@@ -329,8 +329,8 @@ tp_simple_observer_new (TpDBusDaemon *dbus,
  * @account_manager: an account manager, which may not be %NULL
  * @recover: the value of the Observer.Recover D-Bus property
  * @name: the name of the Observer (see #TpBaseClient:name: for details)
- * @unique: the value of the TpBaseClient:uniquify-name: property
- * @callback: the function called when ObserverChannels is called
+ * @uniquify: the value of the #TpBaseClient:uniquify-name: property
+ * @callback: the function called when ObserveChannels is called
  * @user_data: arbitrary user-supplied data passed to @callback
  * @destroy: called with the user_data as argument, when the #TpSimpleObserver
  * is destroyed
@@ -349,7 +349,7 @@ TpBaseClient *
 tp_simple_observer_new_with_am (TpAccountManager *account_manager,
     gboolean recover,
     const gchar *name,
-    gboolean unique,
+    gboolean uniquify,
     TpSimpleObserverObserveChannelsImpl callback,
     gpointer user_data,
     GDestroyNotify destroy)
@@ -358,7 +358,7 @@ tp_simple_observer_new_with_am (TpAccountManager *account_manager,
       "account-manager", account_manager,
       "recover", recover,
       "name", name,
-      "uniquify-name", unique,
+      "uniquify-name", uniquify,
       "callback", callback,
       "user-data", user_data,
       "destroy", destroy,
