@@ -7,6 +7,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <string.h>
 
 #include <telepathy-glib/stream-tube-channel.h>
@@ -18,6 +20,11 @@
 #include "tests/lib/simple-conn.h"
 #include "tests/lib/stream-tube-chan.h"
 
+#ifdef HAVE_GIO_UNIX
+#include <gio/gio.h>
+#include <gio/gunixcredentialsmessage.h>
+#endif
+
 #define BUFFER_SIZE 128
 
 typedef struct {
@@ -44,6 +51,7 @@ TestContext contexts[] = {
 };
 
 static gboolean have_ipv6 = FALSE;
+static gboolean have_creds = FALSE;
 
 typedef struct {
     GMainLoop *mainloop;
@@ -411,6 +419,14 @@ test_accept_success (Test *test,
   guint i = GPOINTER_TO_UINT (data);
   TpContact *contact;
 
+  if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_UNIX &&
+      contexts[i].access_control == TP_SOCKET_ACCESS_CONTROL_CREDENTIALS &&
+      !have_creds)
+    {
+      g_message ("skipped: credentials-passing not supported here");
+      return;
+    }
+
   if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_IPV6 &&
       !have_ipv6)
     {
@@ -518,6 +534,14 @@ test_offer_success (Test *test,
   TpHandle bob_handle;
   TpContact *contact;
 
+  if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_UNIX &&
+      contexts[i].access_control == TP_SOCKET_ACCESS_CONTROL_CREDENTIALS &&
+      !have_creds)
+    {
+      g_message ("skipped: credentials-passing not supported here");
+      return;
+    }
+
   if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_IPV6 &&
       !have_ipv6)
     {
@@ -714,6 +738,14 @@ test_offer_race (Test *test,
   GSocketConnection *conn;
   TpContact *contact;
 
+  if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_UNIX &&
+      contexts[i].access_control == TP_SOCKET_ACCESS_CONTROL_CREDENTIALS &&
+      !have_creds)
+    {
+      g_message ("skipped: credentials-passing not supported here");
+      return;
+    }
+
   if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_IPV6 &&
       !have_ipv6)
     {
@@ -1023,6 +1055,12 @@ main (int argc,
 
   have_ipv6 = check_ipv6_support ();
 
+#ifdef HAVE_GIO_UNIX
+  have_creds = g_unix_credentials_message_is_supported ();
+#else
+  have_creds = FALSE;
+#endif
+
   g_test_add ("/stream-tube/creation", Test, NULL, setup, test_creation,
       teardown);
   g_test_add ("/stream-tube/properties", Test, NULL, setup, test_properties,
